@@ -3,6 +3,8 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 
+import Joi from "joi";
+
 /**
  * JSON serializable metadata type
  */
@@ -27,6 +29,37 @@ export type ClusterId = string;
  */
 export type UpdateClusterModel = Omit<ClusterModel, "id">;
 
+/**
+ * A type validator for `UpdateClusterModel` so that only expected types are present
+ */
+export const updateClusterModelChecker = Joi.object<UpdateClusterModel>({
+  kubeConfigPath: Joi.string()
+    .required()
+    .min(1),
+  contextName: Joi.string()
+    .required()
+    .min(1),
+  workspace: Joi.string()
+    .optional(),
+  workspaces: Joi.array()
+    .items(Joi.string()),
+  preferences: Joi.object(),
+  metadata: Joi.object(),
+  accessibleNamespaces: Joi.array()
+    .items(Joi.string()),
+  labels: Joi.object().pattern(Joi.string(), Joi.string()),
+});
+
+/**
+ * A type validator for just the `id` fields of `ClusterModel`. The rest is
+ * covered by `updateClusterModelChecker`
+ */
+export const clusterModelIdChecker = Joi.object<Pick<ClusterModel, "id">>({
+  id: Joi.string()
+    .required()
+    .min(1),
+});
+
 /**
  * The model for passing cluster data around, including to disk
  */
