@@ -4,10 +4,11 @@
  */
 
 export type KubeResource =
-  "namespaces" | "nodes" | "events" | "resourcequotas" | "services" | "limitranges" |
+  "namespaces" | "nodes" | "events" | "resourcequotas" | "services" | "limitranges" | "leases" |
   "secrets" | "configmaps" | "ingresses" | "networkpolicies" | "persistentvolumeclaims" | "persistentvolumes" | "storageclasses" |
   "pods" | "daemonsets" | "deployments" | "statefulsets" | "replicasets" | "jobs" | "cronjobs" |
-  "endpoints" | "customresourcedefinitions" | "horizontalpodautoscalers" | "podsecuritypolicies" | "poddisruptionbudgets" | "priorityclasses" |
+  "endpoints" | "customresourcedefinitions" | "horizontalpodautoscalers" | "podsecuritypolicies" | "poddisruptionbudgets" |
+  "priorityclasses" | "runtimeclasses" |
   "roles" | "clusterroles" | "rolebindings" | "clusterrolebindings" | "serviceaccounts";
 
 export interface KubeApiResource extends KubeApiResourceData {
@@ -34,6 +35,7 @@ export const apiResourceRecord: Record<KubeResource, KubeApiResourceData> = {
   "jobs": { kind: "Job", group: "batch" },
   "namespaces": { kind: "Namespace" },
   "limitranges": { kind: "LimitRange" },
+  "leases": { kind: "Lease" },
   "networkpolicies": { kind: "NetworkPolicy", group: "networking.k8s.io" },
   "nodes": { kind: "Node" },
   "persistentvolumes": { kind: "PersistentVolume" },
@@ -42,6 +44,7 @@ export const apiResourceRecord: Record<KubeResource, KubeApiResourceData> = {
   "poddisruptionbudgets": { kind: "PodDisruptionBudget", group: "policy" },
   "podsecuritypolicies": { kind: "PodSecurityPolicy", group: "policy" },
   "priorityclasses": { kind: "PriorityClass", group: "scheduling.k8s.io" },
+  "runtimeclasses": { kind: "RuntimeClass", group: "node.k8s.io" },
   "resourcequotas": { kind: "ResourceQuota" },
   "replicasets": { kind: "ReplicaSet", group: "apps" },
   "roles": { kind: "Role", group: "rbac.authorization.k8s.io" },
