@@ -4,7 +4,8 @@
  */
 import { getInjectable } from "@ogre-tools/injectable";
 import { UserStore } from "./user-store";
-import selectedUpdateChannelInjectable from "../application-update/selected-update-channel/selected-update-channel.injectable";
+import selectedUpdateChannelInjectable from "../../features/application-update/common/selected-update-channel/selected-update-channel.injectable";
+import emitAppEventInjectable from "../app-event-bus/emit-event.injectable";
 
 const userStoreInjectable = getInjectable({
   id: "user-store",
@@ -14,6 +15,7 @@ const userStoreInjectable = getInjectable({
 
     return UserStore.createInstance({
       selectedUpdateChannel: di.inject(selectedUpdateChannelInjectable),
+      emitAppEvent: di.inject(emitAppEventInjectable),
     });
   },
 
