@@ -14,7 +14,6 @@ export * from "./convertMemory";
 export * from "./debouncePromise";
 export * from "./delay";
 export * from "./disposer";
-export * from "./downloadFile";
 export * from "./escapeRegExp";
 export * from "./formatDuration";
 export * from "./getRandId";
@@ -22,7 +21,6 @@ export * from "./hash-set";
 export * from "./n-fircate";
 export * from "./noop";
 export * from "./observable-crate/impl";
-export * from "./paths";
 export * from "./promise-exec";
 export * from "./readonly";
 export * from "./reject-promise";
