@@ -5,7 +5,6 @@
 
 // Helper for working with tarball files (.tar, .tgz)
 // Docs: https://github.com/npm/node-tar
-import type { ExtractOptions, FileStat } from "tar";
 import tar from "tar";
 import path from "path";
 import { parse } from "./json";
@@ -35,7 +34,7 @@ export function readFileFromTar<ParseJson extends boolean>({ tarPath, filePath,
       file: tarPath,
       filter: entryPath => path.normalize(entryPath) === filePath,
       sync: true,
-      onentry(entry: FileStat) {
+      onentry(entry) {
         entry.on("data", chunk => {
           fileChunks.push(chunk);
         });
@@ -62,18 +61,10 @@ export async function listTarEntries(filePath: string): Promise<string[]> {
 
   await tar.list({
     file: filePath,
-    onentry: (entry: FileStat) => {
-      entries.push(path.normalize(entry.path as unknown as string));
+    onentry: (entry) => {
+      entries.push(path.normalize(entry.path));
     },
   });
 
   return entries;
 }
-
-export function extractTar(filePath: string, opts: ExtractOptions & { sync?: boolean } = {}) {
-  return tar.extract({
-    file: filePath,
-    cwd: path.dirname(filePath),
-    ...opts,
-  });
-}
