@@ -35,6 +35,15 @@ export function hasTypedProperty<S extends object, K extends PropertyKey, V>(val
   return hasOwnProperty(val, key) && isValid(val[key]);
 }
 
+/**
+ * Narrows `val` to include the property `key` with type string
+ * @param val the value that we are trying to type narrow
+ * @param key The key to test if it is present on the object (must be a literal for tsc to do any meaningful typing)
+ */
+export function hasStringProperty<S extends object, K extends PropertyKey>(val: S, key: K): val is (S & { [key in K]: string }) {
+  return hasOwnProperty(val, key) && isString(val[key]);
+}
+
 /**
  * Narrows `val` to include the property `key` with type `V | undefined` or doesn't contain it
  * @param val the value that we are trying to type narrow
@@ -103,7 +112,7 @@ export function isBoolean(val: unknown): val is boolean {
  * checks if val is of type object and isn't null
  * @param val the value to be checked
  */
-export function isObject(val: unknown): val is object {
+export function isObject(val: unknown): val is Record<string | symbol | number, unknown> {
   return typeof val === "object" && val !== null;
 }
 
