@@ -169,7 +169,10 @@ describe("add custom helm repository in preferences", () => {
               expect(execFileMock).toHaveBeenCalledWith(
                 "some-helm-binary-path",
                 ["repo", "add", "some-custom-repository", "http://some.url"],
-                { "maxBuffer": 34359738368 },
+                {
+                  maxBuffer: 34359738368,
+                  env: {},
+                },
               );
             });
 
@@ -373,7 +376,10 @@ describe("add custom helm repository in preferences", () => {
                     "--cert-file",
                     "some-cert-file",
                   ],
-                  { "maxBuffer": 34359738368 },
+                  {
+                    maxBuffer: 34359738368,
+                    env: {},
+                  },
                 );
               });
             });
