@@ -5,25 +5,32 @@
 import type { RenderResult } from "@testing-library/react";
 import type { ApplicationBuilder } from "../../renderer/components/test-utils/get-application-builder";
 import { getApplicationBuilder } from "../../renderer/components/test-utils/get-application-builder";
+import type { Discover } from "../../renderer/components/test-utils/discovery-of-html-elements";
+import { discoverFor } from "../../renderer/components/test-utils/discovery-of-html-elements";
 
 describe("show-about-using-tray", () => {
   let applicationBuilder: ApplicationBuilder;
   let rendered: RenderResult;
+  let discover: Discover;
 
   beforeEach(async () => {
     applicationBuilder = getApplicationBuilder();
 
     rendered = await applicationBuilder.render();
+    discover = discoverFor(() => rendered);
   });
 
   it("renders", () => {
     expect(rendered.baseElement).toMatchSnapshot();
   });
 
-  it("does not show application preferences page yet", () => {
-    const actual = rendered.queryByTestId("application-preferences-page");
+  it("does not show application preferences yet", () => {
+    const { discovered } = discover.querySingleElement(
+      "preference-page",
+      "application-page",
+    );
 
-    expect(actual).toBeNull();
+    expect(discovered).toBeNull();
   });
 
   describe("when navigating using tray", () => {
@@ -35,10 +42,13 @@ describe("show-about-using-tray", () => {
       expect(rendered.baseElement).toMatchSnapshot();
     });
 
-    it("shows application preferences page", () => {
-      const actual = rendered.getByTestId("application-preferences-page");
+    it("shows application preferences", () => {
+      const { discovered } = discover.getSingleElement(
+        "preference-page",
+        "application-page",
+      );
 
-      expect(actual).not.toBeNull();
+      expect(discovered).not.toBeNull();
     });
   });
 });
