@@ -2,4 +2,5 @@
  * Copyright (c) OpenLens Authors. All rights reserved.
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
-import "@testing-library/jest-dom/extend-expect";
+
+import "@testing-library/jest-dom";
