@@ -4,21 +4,21 @@
  */
 import { getInjectable } from "@ogre-tools/injectable";
 import { getBinaryName } from "../../common/vars";
-import getAbsolutePathInjectable from "../../common/path/get-absolute-path.injectable";
 import normalizedPlatformInjectable from "../../common/vars/normalized-platform.injectable";
 import baseBundledBinariesDirectoryInjectable from "../../common/vars/base-bundled-binaries-dir.injectable";
+import joinPathsInjectable from "../../common/path/join-paths.injectable";
 
 const helmBinaryPathInjectable = getInjectable({
   id: "helm-binary-path",
 
   instantiate: (di) => {
-    const getAbsolutePath = di.inject(getAbsolutePathInjectable);
+    const joinPaths = di.inject(joinPathsInjectable);
     const normalizedPlatform = di.inject(normalizedPlatformInjectable);
     const baseBundledBinariesDirectory = di.inject(baseBundledBinariesDirectoryInjectable);
 
     const helmBinaryName = getBinaryName("helm", { forPlatform: normalizedPlatform });
 
-    return getAbsolutePath(baseBundledBinariesDirectory, helmBinaryName);
+    return joinPaths(baseBundledBinariesDirectory, helmBinaryName);
   },
 });
 
