@@ -3,7 +3,6 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 
-import path from "path";
 import fs from "fs";
 import { promiseExecFile } from "../../common/utils/promise-exec";
 import logger from "../logger";
@@ -15,6 +14,9 @@ import got from "got/dist/source";
 import { promisify } from "util";
 import stream from "stream";
 import { noop } from "lodash/fp";
+import type { JoinPaths } from "../../common/path/join-paths.injectable";
+import type { GetDirnameOfPath } from "../../common/path/get-dirname.injectable";
+import type { GetBasenameOfPath } from "../../common/path/get-basename.injectable";
 
 const initScriptVersionString = "# lens-initscript v3";
 
@@ -33,6 +35,9 @@ export interface KubectlDependencies {
   };
   readonly bundledKubectlVersion: string;
   readonly kubectlVersionMap: Map<string, string>;
+  joinPaths: JoinPaths;
+  getDirnameOfPath: GetDirnameOfPath;
+  getBasenameOfPath: GetBasenameOfPath;
 }
 
 export class Kubectl {
@@ -71,8 +76,8 @@ export class Kubectl {
     }
 
     this.url = `${this.getDownloadMirror()}/v${this.kubectlVersion}/bin/${this.dependencies.normalizedDownloadPlatform}/${this.dependencies.normalizedDownloadArch}/${this.dependencies.kubectlBinaryName}`;
-    this.dirname = path.normalize(path.join(this.getDownloadDir(), this.kubectlVersion));
-    this.path = path.join(this.dirname, this.dependencies.kubectlBinaryName);
+    this.dirname = this.dependencies.joinPaths(this.getDownloadDir(), this.kubectlVersion);
+    this.path = this.dependencies.joinPaths(this.dirname, this.dependencies.kubectlBinaryName);
   }
 
   public getBundledPath() {
@@ -85,7 +90,7 @@ export class Kubectl {
 
   protected getDownloadDir() {
     if (this.dependencies.userStore.downloadBinariesPath) {
-      return path.join(this.dependencies.userStore.downloadBinariesPath, "kubectl");
+      return this.dependencies.joinPaths(this.dependencies.userStore.downloadBinariesPath, "kubectl");
     }
 
     return this.dependencies.directoryForKubectlBinaries;
@@ -104,7 +109,7 @@ export class Kubectl {
     if (!await this.checkBinary(this.getBundledPath(), false)) {
       Kubectl.invalidBundle = true;
 
-      return path.basename(this.getBundledPath());
+      return this.dependencies.getBasenameOfPath(this.getBundledPath());
     }
 
     try {
@@ -246,7 +251,7 @@ export class Kubectl {
   }
 
   public async downloadKubectl() {
-    await ensureDir(path.dirname(this.path), 0o755);
+    await ensureDir(this.dependencies.getDirnameOfPath(this.path), 0o755);
 
     logger.info(`Downloading kubectl ${this.kubectlVersion} from ${this.url} to ${this.path}`);
 
@@ -268,9 +273,9 @@ export class Kubectl {
     const binariesDir = this.dependencies.baseBundeledBinariesDirectory;
     const kubectlPath = this.dependencies.userStore.downloadKubectlBinaries
       ? this.dirname
-      : path.dirname(this.getPathFromPreferences());
+      : this.dependencies.getDirnameOfPath(this.getPathFromPreferences());
 
-    const bashScriptPath = path.join(this.dirname, ".bash_set_path");
+    const bashScriptPath = this.dependencies.joinPaths(this.dirname, ".bash_set_path");
     const bashScript = [
       initScriptVersionString,
       "tempkubeconfig=\"$KUBECONFIG\"",
@@ -292,7 +297,7 @@ export class Kubectl {
       "unset tempkubeconfig",
     ].join("\n");
 
-    const zshScriptPath = path.join(this.dirname, ".zlogin");
+    const zshScriptPath = this.dependencies.joinPaths(this.dirname, ".zlogin");
     const zshScript = [
       initScriptVersionString,
       "tempkubeconfig=\"$KUBECONFIG\"",
