@@ -4,15 +4,15 @@
  */
 import { getInjectable } from "@ogre-tools/injectable";
 import { shellApiRequest } from "./shell-api-request";
-import createShellSessionInjectable from "../../../shell-session/create-shell-session.injectable";
 import shellRequestAuthenticatorInjectable from "./shell-request-authenticator/shell-request-authenticator.injectable";
 import clusterManagerInjectable from "../../../cluster/manager.injectable";
+import openShellSessionInjectable from "../../../shell-session/create-shell-session.injectable";
 
 const shellApiRequestInjectable = getInjectable({
   id: "shell-api-request",
 
   instantiate: (di) => shellApiRequest({
-    createShellSession: di.inject(createShellSessionInjectable),
+    openShellSession: di.inject(openShellSessionInjectable),
     authenticateRequest: di.inject(shellRequestAuthenticatorInjectable).authenticate,
     clusterManager: di.inject(clusterManagerInjectable),
   }),
