@@ -2,8 +2,8 @@
  * Copyright (c) OpenLens Authors. All rights reserved.
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
-import type { Injectable } from "@ogre-tools/injectable";
-import { getInjectable, getInjectionToken, lifecycleEnum } from "@ogre-tools/injectable";
+import type { Injectable, InjectionToken } from "@ogre-tools/injectable";
+import { getInjectable, getInjectionToken } from "@ogre-tools/injectable";
 import { Router } from "./router";
 import parseRequestInjectable from "./parse-request.injectable";
 import type { Route } from "./route";
@@ -13,17 +13,13 @@ export const routeInjectionToken = getInjectionToken<Route<unknown, string>>({
   id: "route-injection-token",
 });
 
-export function getRouteInjectable<
-  T,
-  Path extends string,
->(
+export function getRouteInjectable<T, Path extends string>(
   opts: Omit<Injectable<Route<T, Path>, Route<T, Path>, void>, "lifecycle" | "injectionToken">,
-): Injectable<Route<T, Path>, Route<T, Path>, void> {
-  return {
+) {
+  return getInjectable({
     ...opts,
-    injectionToken: routeInjectionToken as never,
-    lifecycle: lifecycleEnum.singleton as never,
-  };
+    injectionToken: routeInjectionToken as unknown as InjectionToken<Route<T, Path>, void>,
+  });
 }
 
 const routerInjectable = getInjectable({
