@@ -8,17 +8,17 @@ import type { Kubectl } from "../kubectl/kubectl";
 import type WebSocket from "ws";
 import { clearKubeconfigEnvVars } from "../utils/clear-kube-env-vars";
 import path from "path";
-import os, { userInfo } from "os";
+import os from "os";
 import type * as pty from "node-pty";
-import { appEventBus } from "../../common/app-event-bus/event-bus";
-import logger from "../logger";
-import { stat } from "fs/promises";
 import { getOrInsertWith } from "../../common/utils";
 import { type TerminalMessage, TerminalChannels } from "../../common/terminal/channels";
 import type { Logger } from "../../common/logger";
 import type { ComputeShellEnvironment } from "../utils/shell-env/compute-shell-environment.injectable";
 import type { SpawnPty } from "./spawn-pty.injectable";
 import type { InitializableState } from "../../common/initializable-state/create";
+import type { EmitAppEvent } from "../../common/app-event-bus/emit-event.injectable";
+import type { Stat } from "../../common/fs/stat/stat.injectable";
+import type { IComputedValue } from "mobx";
 
 export class ShellOpenError extends Error {
   constructor(message: string, options?: ErrorOptions) {
@@ -108,11 +108,13 @@ export interface ShellSessionDependencies {
   readonly isWindows: boolean;
   readonly isMac: boolean;
   readonly logger: Logger;
-  readonly resolvedShell: string | undefined;
+  readonly userShellSetting: IComputedValue<string>;
   readonly appName: string;
   readonly buildVersion: InitializableState<string>;
   computeShellEnvironment: ComputeShellEnvironment;
   spawnPty: SpawnPty;
+  emitAppEvent: EmitAppEvent;
+  stat: Stat;
 }
 
 export interface ShellSessionArgs {
@@ -168,18 +170,18 @@ export abstract class ShellSession {
       })
     ));
 
-    logger.info(`[SHELL-SESSION]: PTY for ${this.terminalId} is ${resume ? "resumed" : "started"} with PID=${shellProcess.pid}`);
+    this.dependencies.logger.info(`[SHELL-SESSION]: PTY for ${this.terminalId} is ${resume ? "resumed" : "started"} with PID=${shellProcess.pid}`);
 
     return { shellProcess, resume };
   }
 
-  constructor(protected readonly dependencies: ShellSessionDependencies, args: ShellSessionArgs) {
-    this.cluster = args.cluster;
-    this.kubectl = args.kubectl;
-    this.websocket = args.websocket;
+  constructor(protected readonly dependencies: ShellSessionDependencies, { kubectl, websocket, cluster, tabId: terminalId }: ShellSessionArgs) {
+    this.kubectl = kubectl;
+    this.websocket = websocket;
+    this.cluster = cluster;
     this.kubeconfigPathP = this.cluster.getProxyKubeconfigPath();
     this.kubectlBinDirP = this.kubectl.binDir();
-    this.terminalId = `${this.cluster.id}:${args.tabId}`;
+    this.terminalId = `${cluster.id}:${terminalId}`;
   }
 
   protected send(message: TerminalMessage): void {
@@ -214,7 +216,7 @@ export abstract class ShellSession {
       }
 
       try {
-        const stats = await stat(potentialCwd);
+        const stats = await this.dependencies.stat(potentialCwd);
 
         if (stats.isDirectory()) {
           return potentialCwd;
@@ -238,7 +240,7 @@ export abstract class ShellSession {
     this.running = true;
     shellProcess.onData(data => this.send({ type: TerminalChannels.STDOUT, data }));
     shellProcess.onExit(({ exitCode }) => {
-      logger.info(`[SHELL-SESSION]: shell has exited for ${this.terminalId} closed with exitcode=${exitCode}`);
+      this.dependencies.logger.info(`[SHELL-SESSION]: shell has exited for ${this.terminalId} closed with exitcode=${exitCode}`);
 
       // This might already be false because of the kill() within the websocket.on("close") handler
       if (this.running) {
@@ -256,11 +258,11 @@ export abstract class ShellSession {
     this.websocket
       .on("message", (rawData: unknown): void => {
         if (!this.running) {
-          return void logger.debug(`[SHELL-SESSION]: received message from ${this.terminalId}, but shellProcess isn't running`);
+          return void this.dependencies.logger.debug(`[SHELL-SESSION]: received message from ${this.terminalId}, but shellProcess isn't running`);
         }
 
         if (!(rawData instanceof Buffer)) {
-          return void logger.error(`[SHELL-SESSION]: Received message non-buffer message.`, { rawData });
+          return void this.dependencies.logger.error(`[SHELL-SESSION]: Received message non-buffer message.`, { rawData });
         }
 
         const data = rawData.toString();
@@ -276,18 +278,18 @@ export abstract class ShellSession {
               shellProcess.resize(message.data.width, message.data.height);
               break;
             case TerminalChannels.PING:
-              logger.silly(`[SHELL-SESSION]: ${this.terminalId} ping!`);
+              this.dependencies.logger.silly(`[SHELL-SESSION]: ${this.terminalId} ping!`);
               break;
             default:
-              logger.warn(`[SHELL-SESSION]: unknown or unhandleable message type for ${this.terminalId}`, message);
+              this.dependencies.logger.warn(`[SHELL-SESSION]: unknown or unhandleable message type for ${this.terminalId}`, message);
               break;
           }
         } catch (error) {
-          logger.error(`[SHELL-SESSION]: failed to handle message for ${this.terminalId}`, error);
+          this.dependencies.logger.error(`[SHELL-SESSION]: failed to handle message for ${this.terminalId}`, error);
         }
       })
       .once("close", code => {
-        logger.info(`[SHELL-SESSION]: websocket for ${this.terminalId} closed with code=${WebSocketCloseEvent[code]}(${code})`, { cluster: this.cluster.getMeta() });
+        this.dependencies.logger.info(`[SHELL-SESSION]: websocket for ${this.terminalId} closed with code=${WebSocketCloseEvent[code]}(${code})`, { cluster: this.cluster.getMeta() });
 
         const stopShellSession = this.running
           && (
@@ -302,16 +304,16 @@ export abstract class ShellSession {
           this.running = false;
 
           try {
-            logger.info(`[SHELL-SESSION]: Killing shell process (pid=${shellProcess.pid}) for ${this.terminalId}`);
+            this.dependencies.logger.info(`[SHELL-SESSION]: Killing shell process (pid=${shellProcess.pid}) for ${this.terminalId}`);
             shellProcess.kill();
             ShellSession.processes.delete(this.terminalId);
           } catch (error) {
-            logger.warn(`[SHELL-SESSION]: failed to kill shell process (pid=${shellProcess.pid}) for ${this.terminalId}`, error);
+            this.dependencies.logger.warn(`[SHELL-SESSION]: failed to kill shell process (pid=${shellProcess.pid}) for ${this.terminalId}`, error);
           }
         }
       });
 
-    appEventBus.emit({ name: this.ShellType, action: "open" });
+    this.dependencies.emitAppEvent({ name: this.ShellType, action: "open" });
   }
 
   protected getPathEntries(): string[] {
@@ -337,7 +339,7 @@ export abstract class ShellSession {
   }
 
   protected async getShellEnv() {
-    const shell = this.dependencies.resolvedShell || userInfo().shell;
+    const shell = this.dependencies.userShellSetting.get();
     const result = await this.dependencies.computeShellEnvironment(shell);
     const rawEnv = (() => {
       if (result.callWasSuccessful) {
