@@ -14,9 +14,7 @@ const stopSyncingThemeFromOperatingSystemInjectable = getInjectable({
 
     return {
       id: "stop-syncing-theme-from-operating-system",
-      run: async () => {
-        await syncTheme.stop();
-      },
+      run: () => void syncTheme.stop(),
     };
   },
 
