@@ -7,7 +7,6 @@ import "./helm-charts.scss";
 
 import React, { Component } from "react";
 import { observer } from "mobx-react";
-import { helmChartStore } from "./helm-chart.store";
 import type { HelmChart } from "../../../common/k8s-api/endpoints/helm-charts.api";
 import { HelmChartDetails } from "./helm-chart-details";
 import { ItemListLayout } from "../item-object-list/list-layout";
@@ -21,6 +20,7 @@ import navigateToHelmChartsInjectable from "../../../common/front-end-routing/ro
 import { HelmChartIcon } from "./icon";
 import helmChartsInjectable from "./helm-charts/helm-charts.injectable";
 import selectedHelmChartInjectable from "./helm-charts/selected-helm-chart.injectable";
+import { noop } from "lodash";
 
 enum columnId {
   name = "name",
@@ -35,9 +35,7 @@ interface Dependencies {
     chartName: IComputedValue<string>;
     repo: IComputedValue<string>;
   };
-
   navigateToHelmCharts: NavigateToHelmCharts;
-
   charts: IAsyncComputed<HelmChart[]>;
   selectedChart: IComputedValue<HelmChart | undefined>;
 }
@@ -69,17 +67,31 @@ class NonInjectedHelmCharts extends Component<Dependencies> {
   };
 
   render() {
+    const { charts } = this.props;
     const selectedChart = this.props.selectedChart.get();
 
     return (
       <SiblingsInTabLayout>
         <div data-testid="page-for-helm-charts" style={{ display: "none" }}/>
 
-        <ItemListLayout
+        <ItemListLayout<HelmChart, false>
           isConfigurable
           tableId="helm_charts"
           className="HelmCharts"
-          store={helmChartStore}
+          store={{
+            get isLoaded() {
+              return !charts.pending.get();
+            },
+            failedLoading: false,
+            getTotalCount: () => charts.value.get().length,
+            isSelected: (item) => item === selectedChart,
+            toggleSelection: noop,
+            isSelectedAll: () => false,
+            toggleSelectionAll: () => false,
+            pickOnlySelected: () => [],
+            removeSelectedItems: async () => {},
+          }}
+          preloadStores={false}
           getItems={() => this.props.charts.value.get()}
           isSelectable={false}
           sortingCallbacks={{
@@ -132,16 +144,12 @@ class NonInjectedHelmCharts extends Component<Dependencies> {
   }
 }
 
-export const HelmCharts = withInjectables<Dependencies>(
-  NonInjectedHelmCharts,
-
-  {
-    getProps: (di) => ({
-      routeParameters: di.inject(helmChartsRouteParametersInjectable),
-      navigateToHelmCharts: di.inject(navigateToHelmChartsInjectable),
-      charts: di.inject(helmChartsInjectable),
-      selectedChart: di.inject(selectedHelmChartInjectable),
-    }),
-  },
-);
+export const HelmCharts = withInjectables<Dependencies>(NonInjectedHelmCharts, {
+  getProps: (di) => ({
+    routeParameters: di.inject(helmChartsRouteParametersInjectable),
+    navigateToHelmCharts: di.inject(navigateToHelmChartsInjectable),
+    charts: di.inject(helmChartsInjectable),
+    selectedChart: di.inject(selectedHelmChartInjectable),
+  }),
+});
 
