@@ -5,15 +5,15 @@
 import { getInjectable } from "@ogre-tools/injectable";
 
 import releasesInjectable from "../releases.injectable";
-import type { CallForCreateHelmRelease } from "./call-for-create-helm-release.injectable";
-import callForCreateHelmReleaseInjectable from "./call-for-create-helm-release.injectable";
+import type { RequestCreateHelmRelease } from "../../../../common/k8s-api/endpoints/helm-releases.api/request-create.injectable";
+import requestCreateHelmReleaseInjectable from "../../../../common/k8s-api/endpoints/helm-releases.api/request-create.injectable";
 
 const createReleaseInjectable = getInjectable({
   id: "create-release",
 
-  instantiate: (di): CallForCreateHelmRelease => {
+  instantiate: (di): RequestCreateHelmRelease => {
     const releases = di.inject(releasesInjectable);
-    const callForCreateRelease = di.inject(callForCreateHelmReleaseInjectable);
+    const callForCreateRelease = di.inject(requestCreateHelmReleaseInjectable);
 
     return async (payload) => {
       const release = await callForCreateRelease(payload);
