@@ -13,8 +13,7 @@ import { PodDetailsTolerations } from "../+workloads-pods/pod-details-toleration
 import { PodDetailsAffinities } from "../+workloads-pods/pod-details-affinities";
 import { disposeOnUnmount, observer } from "mobx-react";
 import type { KubeObjectDetailsProps } from "../kube-object-details";
-import type { PodMetricData } from "../../../common/k8s-api/endpoints";
-import { getMetricsForReplicaSets, ReplicaSet } from "../../../common/k8s-api/endpoints";
+import { ReplicaSet } from "../../../common/k8s-api/endpoints";
 import { ResourceMetrics, ResourceMetricsText } from "../resource-metrics";
 import { PodCharts, podMetricTabs } from "../+workloads-pods/pod-charts";
 import { PodDetailsList } from "../+workloads-pods/pod-details-list";
@@ -30,6 +29,8 @@ import type { ReplicaSetStore } from "./store";
 import replicaSetStoreInjectable from "./store.injectable";
 import type { GetActiveClusterEntity } from "../../api/catalog/entity/get-active-cluster-entity.injectable";
 import getActiveClusterEntityInjectable from "../../api/catalog/entity/get-active-cluster-entity.injectable";
+import type { ReplicaSetPodMetricData, RequestPodMetricsForReplicaSets } from "../../../common/k8s-api/endpoints/metrics.api/request-pod-metrics-for-replica-sets.injectable";
+import requestPodMetricsForReplicaSetsInjectable from "../../../common/k8s-api/endpoints/metrics.api/request-pod-metrics-for-replica-sets.injectable";
 
 export interface ReplicaSetDetailsProps extends KubeObjectDetailsProps<ReplicaSet> {
 }
@@ -39,11 +40,12 @@ interface Dependencies {
   podStore: PodStore;
   replicaSetStore: ReplicaSetStore;
   getActiveClusterEntity: GetActiveClusterEntity;
+  requestPodMetricsForReplicaSets: RequestPodMetricsForReplicaSets;
 }
 
 @observer
 class NonInjectedReplicaSetDetails extends React.Component<ReplicaSetDetailsProps & Dependencies> {
-  @observable metrics: PodMetricData | null = null;
+  @observable metrics: ReplicaSetPodMetricData | null = null;
 
   constructor(props: ReplicaSetDetailsProps & Dependencies) {
     super(props);
@@ -63,9 +65,9 @@ class NonInjectedReplicaSetDetails extends React.Component<ReplicaSetDetailsProp
   }
 
   loadMetrics = async () => {
-    const { object: replicaSet } = this.props;
+    const { object: replicaSet, requestPodMetricsForReplicaSets } = this.props;
 
-    this.metrics = await getMetricsForReplicaSets([replicaSet], replicaSet.getNs(), "");
+    this.metrics = await requestPodMetricsForReplicaSets([replicaSet], replicaSet.getNs());
   };
 
   render() {
@@ -144,5 +146,6 @@ export const ReplicaSetDetails = withInjectables<Dependencies, ReplicaSetDetails
     podStore: di.inject(podStoreInjectable),
     replicaSetStore: di.inject(replicaSetStoreInjectable),
     getActiveClusterEntity: di.inject(getActiveClusterEntityInjectable),
+    requestPodMetricsForReplicaSets: di.inject(requestPodMetricsForReplicaSetsInjectable),
   }),
 });
