@@ -4,9 +4,12 @@
  */
 import { getInjectable } from "@ogre-tools/injectable";
 
+export type RequestAnimationFrame = (callback: () => void) => void;
+
 const requestAnimationFrameInjectable = getInjectable({
   id: "request-animation-frame",
-  instantiate: () => (callback: () => void) => requestAnimationFrame(callback),
+  // NOTE: this cannot be simplified to just `=> requestAnimationFrame` else an Illegal Invocation error will be thrown
+  instantiate: (): RequestAnimationFrame => (callback) => requestAnimationFrame(callback),
   causesSideEffects: true,
 });
 
