@@ -7,12 +7,13 @@ import type { IComputedValue } from "mobx";
 import { computed } from "mobx";
 import type { TabId } from "../dock/store";
 import type { SearchStore } from "../../../search-store/search-store";
-import type { Pod } from "../../../../common/k8s-api/endpoints";
+import type { Pod, PodLogsQuery } from "../../../../common/k8s-api/endpoints";
 import { isDefined } from "../../../utils";
 import assert from "assert";
 import type { GetPodById } from "../../+workloads-pods/get-pod-by-id.injectable";
 import type { GetPodsByOwnerId } from "../../+workloads-pods/get-pods-by-owner-id.injectable";
 import type { LoadLogs } from "./load-logs.injectable";
+import type { ResourceDescriptor } from "../../../../common/k8s-api/kube-api";
 
 export interface LogTabViewModelDependencies {
   getLogs: (tabId: TabId) => string[];
@@ -27,6 +28,8 @@ export interface LogTabViewModelDependencies {
   getPodById: GetPodById;
   getPodsByOwnerId: GetPodsByOwnerId;
   areLogsPresent: (tabId: TabId) => boolean;
+  downloadLogs: (filename: string, logs: string[]) => void;
+  downloadAllLogs: (params: ResourceDescriptor, query: PodLogsQuery) => Promise<void>;
   searchStore: SearchStore;
 }
 
@@ -77,4 +80,32 @@ export class LogTabViewModel {
   reloadLogs = () => this.dependencies.reloadLogs(this.tabId, this.pod, this.logTabData);
   renameTab = (title: string) => this.dependencies.renameTab(this.tabId, title);
   stopLoadingLogs = () => this.dependencies.stopLoadingLogs(this.tabId);
+
+  downloadLogs = () => {
+    const pod = this.pod.get();
+    const tabData = this.logTabData.get();
+
+    if (pod && tabData) {
+      const fileName = pod.getName();
+      const logsToDownload: string[] = tabData.showTimestamps
+        ? this.logs.get()
+        : this.logsWithoutTimestamps.get();
+
+      this.dependencies.downloadLogs(`${fileName}.log`, logsToDownload);
+    }
+  };
+
+  downloadAllLogs = () => {
+    const pod = this.pod.get();
+    const tabData = this.logTabData.get();
+
+    if (pod && tabData) {
+      const params = { name: pod.getName(), namespace: pod.getNs() };
+      const query = { timestamps: tabData.showTimestamps, previous: tabData.showPrevious };
+
+      return this.dependencies.downloadAllLogs(params, query);
+    }
+
+    return;
+  };
 }
