@@ -34,6 +34,13 @@ import User from "./user.svg";
 import Users from "./users.svg";
 import Wheel from "./wheel.svg";
 import Workloads from "./workloads.svg";
+import type { Logger } from "../../../common/logger";
+import { withInjectables } from "@ogre-tools/injectable-react";
+import loggerInjectable from "../../../common/logger.injectable";
+
+const hrefValidation = /https?:\/\//;
+
+const hrefIsSafe = (href: string) => Boolean(href.match(hrefValidation));
 
 /**
  * Mapping between the local file names and the svgs
@@ -155,16 +162,21 @@ export function isSvg(content: string): boolean {
   return String(content).includes("<svg");
 }
 
-const RawIcon = withTooltip((props: IconProps) => {
+interface Dependencies {
+  logger: Logger;
+}
+
+const RawIcon = (props: IconProps & Dependencies) => {
   const ref = createRef<HTMLAnchorElement>();
 
   const {
-  // skip passing props to icon's html element
+    // skip passing props to icon's html element
     className, href, link, material, svg, size, smallest, small, big,
     disabled, sticker, active,
     focusable = true,
     children,
     interactive, onClick, onKeyDown,
+    logger,
     ...elemProps
   } = props;
   const isInteractive = interactive ?? !!(onClick || href || link);
@@ -245,16 +257,27 @@ const RawIcon = withTooltip((props: IconProps) => {
   }
 
   if (href) {
-    return (
-      <a
-        {...iconProps}
-        href={href}
-        ref={ref}
-      />
-    );
+    if (hrefIsSafe(href)) {
+      return (
+        <a
+          {...iconProps}
+          href={href}
+          ref={ref}
+        />
+      );
+    }
+
+    logger.warn("[ICON]: href prop is unsafe, blocking", { href });
   }
 
   return <i {...iconProps} ref={ref} />;
+};
+
+const InjectedIcon = withInjectables<Dependencies, IconProps>(RawIcon, {
+  getProps: (di, props) => ({
+    ...props,
+    logger: di.inject(loggerInjectable),
+  }),
 });
 
-export const Icon = Object.assign(RawIcon, { isSvg });
+export const Icon = Object.assign(withTooltip(InjectedIcon), { isSvg });
