@@ -5,7 +5,6 @@
 
 import { asLegacyGlobalFunctionForExtensionApi } from "../../extensions/as-legacy-globals-for-extension-api/as-legacy-global-function-for-extension-api";
 import { asLegacyGlobalForExtensionApi } from "../../extensions/as-legacy-globals-for-extension-api/as-legacy-global-object-for-extension-api";
-import matchRouteInjectable from "./match-route.injectable";
 import navigateInjectable from "./navigate.injectable";
 import observableHistoryInjectable from "./observable-history.injectable";
 
@@ -21,9 +20,4 @@ export const navigation = asLegacyGlobalForExtensionApi(observableHistoryInjecta
  */
 export const navigate = asLegacyGlobalFunctionForExtensionApi(navigateInjectable);
 
-/**
- * @deprecated use `di.inject(matchRouteInjectable)` instead
- */
-export const matchRoute = asLegacyGlobalFunctionForExtensionApi(matchRouteInjectable);
-
 export * from "./page-param";
