@@ -5,7 +5,7 @@
 import { getInjectable } from "@ogre-tools/injectable";
 import userStoreInjectable from "../../common/user-store/user-store.injectable";
 import { beforeFrameStartsInjectionToken } from "../before-frame-starts/before-frame-starts-injection-token";
-import initDefaultUpdateChannelInjectableInjectable from "../vars/default-update-channel/init.injectable";
+import initDefaultUpdateChannelInjectable from "../vars/default-update-channel/init.injectable";
 
 const initUserStoreInjectable = getInjectable({
   id: "init-user-store",
@@ -13,8 +13,9 @@ const initUserStoreInjectable = getInjectable({
     const userStore = di.inject(userStoreInjectable);
 
     return {
+      id: "init-user-store",
       run: () => userStore.load(),
-      runAfter: di.inject(initDefaultUpdateChannelInjectableInjectable),
+      runAfter: di.inject(initDefaultUpdateChannelInjectable),
     };
   },
   injectionToken: beforeFrameStartsInjectionToken,
