@@ -6,9 +6,10 @@
 // Type guard for checking valid react node to use in render
 import type { ReactNode } from "react";
 import React from "react";
+import { isObject } from "../../common/utils";
 
-export function isReactNode(node: ReactNode): node is ReactNode {
-  return React.isValidElement(node)
+export function isReactNode(node: unknown): node is ReactNode {
+  return (isObject(node) && React.isValidElement(node))
     || Array.isArray(node) && node.every(isReactNode)
     || node == null
     || typeof node !== "object";
